@@ -723,7 +723,7 @@ def test_plain_stopall(testdir):
     assert "RuntimeError" not in result.stderr.str()
 
 
-def test_abort_context_manager(mocker):
+def test_abort_patch_object_context_manager(mocker):
     class A(object):
         def doIt(self):
             return False
@@ -740,3 +740,16 @@ def test_abort_context_manager(mocker):
     )
 
     assert str(excinfo.value) == expected_error_msg
+
+
+def test_abort_patch_context_manager(mocker):
+    with pytest.raises(ValueError) as excinfo:
+        with mocker.patch("some_package"):
+            pass
+
+    expected_error_msg = (
+        "Using mocker in a with context is not supported. "
+        "https://github.com/pytest-dev/pytest-mock#note-about-usage-as-context-manager"
+    )
+
+    assert str(excinfo.value) == expected_error_msg
